@@ -17,6 +17,7 @@ DATA_FOLDER = os.path.dirname( os.path.dirname(os.path.realpath(__file__)) ) + "
 DATASET_MAP = {'s4_formula': ('7341_C1.csv', ',', False ,'7341_C1 desc.txt'),
 's3_formula': ('B3.csv', ',', False ,'B3 desc.txt'),
 's4_formula_c2': ('7341_C2.csv', ',', True ,'7341_C2 desc.txt'),
+'s4_formula_c3': ('7341.csv', ',', True ,'7341 desc.txt'),
 'milk_tablet_candy': ('734b.csv',',', False,'734b desc.txt'),
 'yogurt': ('7346.csv',',', True,'7346 desc.txt'),
 'vintage': ('7344.txt','\t', False,'7344 desc.txt'),
@@ -42,6 +43,7 @@ def id_to_path(id):
 def load_dataset(id, SD = 1, shift = 200, x_range = None, y_subset=None, display = True):
     
     path, delimiter, has_y, path_desc = id_to_path(id)
+    print('load dataset from', path)
 
     if display:
         X, y, X_names = peek_dataset(DATA_FOLDER + path, delimiter, has_y, SD, shift, x_range, y_subset)
